DirectorySelector class
A class that provides functionality for selecting directories.
This class can be used to open a directory picker dialog and retrieve the selected directory path.
Constructors
Properties
- console → Console
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
confirmEntireProject(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectFolderPath(
) → String - Selects a folder path.
-
selectOperation(
) → OperationType -
selectSpecificFiles(
) → String - Selects specific files from a directory.
-
selectTargetPath(
OperationType operationType) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited